@@ -108,14 +108,76 @@
 
   method <- match.arg(method)
   mvn_method <- match.arg(mvn_method)
+  fam_type <- family_type(model)
 
-  # start my getting draws of expectation
-  sim_eta <- fitted_samples(model,
-    n = n, data = data, seed = seed,
-    scale = "response", method = method, n_cores = n_cores, burnin = burnin,
-    thin = thin, t_df = t_df, rw_scale = rw_scale, freq = freq,
-    unconditional = unconditional, weights = weights, newdata = newdata,
-    ncores = ncores, draws = draws, mvn_method = mvn_method, ...
+  if (!is.null(newdata)) {
+    newdata_deprecated()
+  }
+
+  if (!is.null(ncores)) {
+    message("Argument `ncores` is deprecated. Use `n_cores` instead.")
+    n_cores <- ncores
+  }
+
+  do_posterior_samples(
+    model = model, n = n, data = data, seed = seed, method = method,
+    n_cores = n_cores, burnin = burnin, thin = thin, t_df = t_df,
+    rw_scale = rw_scale, freq = freq, unconditional = unconditional,
+    weights = weights, draws = draws, mvn_method = mvn_method, ...
+  )
+}
+
+#' @export
+#' @rdname posterior_samples
+`posterior_samples.scam` <- function(
+  model, n = 1, data = NULL, seed = NULL,
+  method = c("gaussian", "mh", "inla", "user"),
+  n_cores = 1, burnin = 1000, thin = 1, t_df = 40, rw_scale = 0.25,
+  freq = FALSE, unconditional = FALSE,
+  weights = NULL, draws = NULL, mvn_method = c("mvnfast", "mgcv"), ...
+) {
+  do_posterior_samples(
+    model = model, n = n, data = data, seed = seed, method = method,
+    n_cores = n_cores, burnin = burnin, thin = thin, t_df = t_df,
+    rw_scale = rw_scale, freq = freq, unconditional = unconditional,
+    weights = weights, draws = draws, mvn_method = mvn_method, ...
+  )
+}
+
+`do_posterior_samples` <- function(
+  model,
+  n = 1,
+  data = NULL,
+  seed = NULL,
+  method = c("gaussian", "mh", "inla", "user"),
+  n_cores = 1,
+  burnin = 1000,
+  thin = 1,
+  t_df = 40,
+  rw_scale = 0.25,
+  freq = FALSE,
+  unconditional = FALSE,
+  weights = NULL,
+  draws = NULL,
+  mvn_method = c("mvnfast", "mgcv"),
+  ...
+) {
+  # generate new response data from the model including the uncertainty in
+  # the model.
+
+  method <- match.arg(method)
+  mvn_method <- match.arg(mvn_method)
+  fam_type <- family_type(model)
+
+  # start getting draws of expectation
+  # - some families need linear predictor values/matrix, e.g., multinom(),
+  #   but we'll handle that later by not using the family()$rd
+  sim_eta <- fitted_samples(
+    model, n = n, data = data, seed = seed, scale = "response",
+    method = method, n_cores = n_cores, burnin = burnin, thin = thin,
+    t_df = t_df, rw_scale = rw_scale, freq = freq,
+    unconditional = unconditional, weights = weights,
+    draws = draws, mvn_method = mvn_method, ...
   )
 
   if (!exists(".Random.seed", envir = .GlobalEnv, inherits = FALSE)) {
@@ -131,16 +193,12 @@
   }
 
   ## rd function if available
-  rd_fun <- get_family_rd(model)
+  rd_fun <- choose_rd_fun(model)
 
   ## dispersion or scale variable for simulation
-  scale <- model[["sig2"]]
+  scale_p <- model[["sig2"]]
   if (is.null(scale)) {
-    scale <- summary(model)[["dispersion"]]
-  }
-
-  if (!is.null(newdata)) {
-    newdata_deprecated()
+    scale_p <- summary(model)[["dispersion"]]
   }
 
   if (is.null(data)) {
@@ -156,13 +214,60 @@
   weights <- rep(weights, times = n)
   # scale <- rep(scale, times = n)
 
-  # replace fitted with
-  sim_eta <- sim_eta |>
-    mutate(.response = rd_fun(
-      mu = .data$.fitted, wt = weights,
-      scale = scale
-    )) |>
-    select(all_of(c(".row", ".draw", ".response")))
+  # replace fitted with simulated response
+  # need to handle mvn() and multinom() with multiple linear predictors that
+  # are all really just location parameters
+  if (is_multivariate_y(model)) {
+    sim_eta_w <- sim_eta |>
+      pivot_wider(
+        id_cols = all_of(c(".row", ".draw")),
+        values_from = ".fitted",
+        names_from = ".parameter"
+      )
+    # Different multivariate models need different handling because they expect
+    # (intake) and return different kinds of things. multinom() for example
+    # should return a predicted category for each sample, so the output looks
+    # more like a normal/standard family. mvn(), however, returns 1 value per
+    # response per draw
+    if (identical(fam_type, "multinom")) {
+      sim_eta <- sim_eta_w |>
+        select(all_of(c(".row", ".draw"))) |>
+        bind_cols(
+          rd_fun(
+            mu = sim_eta_w[, -c(1, 2)] |> as.matrix(),
+            wt = weights,
+            scale = scale_p
+          ) |>
+            as_tibble() |>
+            rename(".response" = "value")
+        )
+    } else if (identical(fam_type, "multivariate_normal")) {
+      sim_eta <- sim_eta_w |>
+        select(all_of(c(".row", ".draw"))) |>
+        bind_cols(
+          rd_fun(
+            mu = sim_eta_w[, -c(1, 2)] |> as.matrix(),
+            wt = weights,
+            scale = scale_p
+          ) |>
+            as_tibble()
+        ) |>
+        pivot_longer(
+          cols = !c(".row", ".draw"),
+          values_to = ".response",
+          names_to = ".parameter"
+        )
+    } else {
+      stop("Unexpected multivariate model; file a bug report please!")
+    }
+  } else {
+    sim_eta <- sim_eta |>
+      mutate(.response = rd_fun(
+        mu = .data$.fitted, wt = weights,
+        scale = scale_p
+      )) |>
+      select(all_of(c(".row", ".draw", ".response")))
+  }
 
   ## add classes
   class(sim_eta) <- c("posterior_samples", class(sim_eta))
@@ -226,11 +331,6 @@
   fitted_samples(model$gam, ...)
 }
 
-#' @export
-`fitted_samples.scam` <- function(model, ...) {
-  fitted_samples.gam(model, ...)
-}
-
 #' @export
 #'
 #' @rdname fitted_samples
@@ -264,13 +364,70 @@
 #' options(op)
 #' }
 `fitted_samples.gam` <- function(
-    model, n = 1, data = newdata, seed = NULL,
-    scale = c("response", "linear_predictor"),
-    method = c("gaussian", "mh", "inla", "user"),
-    n_cores = 1, burnin = 1000, thin = 1, t_df = 40, rw_scale = 0.25,
-    freq = FALSE, unconditional = FALSE, draws = NULL,
-    mvn_method = c("mvnfast", "mgcv"),
-    ..., newdata = NULL, ncores = NULL) {
+  model, n = 1, data = newdata, seed = NULL,
+  scale = c("response", "linear_predictor"),
+  method = c("gaussian", "mh", "inla", "user"),
+  n_cores = 1, burnin = 1000, thin = 1, t_df = 40, rw_scale = 0.25,
+  freq = FALSE, unconditional = FALSE, draws = NULL,
+  mvn_method = c("mvnfast", "mgcv"),
+  ..., newdata = NULL, ncores = NULL
+) {
+
+  if (!is.null(newdata)) {
+    newdata_deprecated()
+  }
+
+  if (!is.null(ncores)) {
+    message("Argument `ncores` is deprecated. Use `n_cores` instead.")
+    n_cores <- ncores
+  }
+
+  do_fitted_samples(
+    model = model, n = n, data = data, seed = seed, scale = scale,
+    method = method, n_cores = n_cores, burnin = burnin, thin = thin,
+    t_df = t_df, rw_scale = rw_scale, freq = freq,
+    unconditional = unconditional, draws = draws, mvn_method = mvn_method,
+    ...
+  )
+}
+
+#' @export
+#' @rdname fitted_samples
+`fitted_samples.scam` <- function(
+  model, n = 1, data = NULL, seed = NULL,
+  scale = c("response", "linear_predictor"),
+  method = c("gaussian", "mh", "inla", "user"),
+  n_cores = 1, burnin = 1000, thin = 1, t_df = 40, rw_scale = 0.25,
+  freq = FALSE, unconditional = FALSE, draws = NULL,
+  mvn_method = c("mvnfast", "mgcv"), ...
+) {
+  do_fitted_samples(
+    model = model, n = n, data = data, seed = seed, scale = scale,
+    method = method, n_cores = n_cores, burnin = burnin, thin = thin,
+    t_df = t_df, rw_scale = rw_scale, freq = freq,
+    unconditional = unconditional, draws = draws, mvn_method = mvn_method,
+    ...
+  )
+}
+
+`do_fitted_samples` <- function(
+  model,
+  n = 1,
+  data = NULL,
+  seed = NULL,
+  scale = c("response", "linear_predictor"),
+  method = c("gaussian", "mh", "inla", "user"),
+  n_cores = 1,
+  burnin = 1000,
+  thin = 1,
+  t_df = 40,
+  rw_scale = 0.25,
+  freq = FALSE,
+  unconditional = FALSE,
+  draws = NULL,
+  mvn_method = c("mvnfast", "mgcv"),
+  ...
+) {
   if (!exists(".Random.seed", envir = .GlobalEnv, inherits = FALSE)) {
     runif(1)
   }
@@ -283,15 +440,6 @@
     on.exit(assign(".Random.seed", R.seed, envir = .GlobalEnv))
   }
 
-  if (!is.null(newdata)) {
-    newdata_deprecated()
-  }
-
-  if (!is.null(ncores)) {
-    message("Argument `ncores` is deprecated. Use `n_cores` instead.")
-    n_cores <- ncores
-  }
-
   if (is.null(data)) {
     data <- model[["model"]]
   }
@@ -310,40 +458,74 @@
   )
   ## betas is for *all* coefs, including distributional parameters
   lss_idx <- lss_eta_index(model)
-  if (gen_fam <- inherits(family(model), "general.family")) {
-    warning("Currently, only for LSS families where location is the mean.")
-    lss_loc <- lss_idx[[1L]] # for now just take the location linpred
+  gen_fam <- inherits(family(model), "general.family")
+  if (gen_fam) {
+    # some general families should allow all linear predictors;
+    # e.g., mvn(), multinom()
+    fam_nam <- family_name(model)
+    if (grepl("^Multivariate normal", fam_nam) || grepl("^multinom", fam_nam)) {
+      lss_loc <- lss_idx # for mvn we want to loop over all the linpreds
+    } else {
+      warning("Currently, only for LSS families where location is the mean.")
+      lss_loc <- lss_idx[[1L]] # for now just take the location linpred
+      lss_idx <- lss_idx[1L] # keep as a list
+    }
   } else {
     lss_loc <- lss_idx[[1L]]
+    lss_idx <- lss_idx[1L] # keep as a list
+  }
+  # function to control predictions
+  pred_fun <- function(Xp, betas, lss_loc, scale) {
+    sims <- Xp[, lss_loc, drop = FALSE] %*% t(betas[, lss_loc, drop = FALSE])
+    # handle the offset if present; it is an attribute on the Xp matrix
+    # it is a list - with 1 component if a normal model and `l` components if it
+    # is a model with `l` linear predictors.
+    m_offset <- attr(Xp, "model.offset")
+    if (is.list(m_offset)) {
+      m_offset <- m_offset[[1L]] # only for location ?
+    }
+    if (!is.null(m_offset)) {
+      sims <- sims + m_offset
+    }
+    # handle transformation to response scale
+    if (isTRUE(identical(scale, "response"))) {
+      ilink <- inv_link(model, parameter = "location")
+      sims <- ilink(sims)
+    }
+    colnames(sims) <- paste0(".V", seq_len(NCOL(sims)))
+    sims <- as_tibble(sims)
+    names(sims) <- as.character(seq_len(ncol(sims)))
+    sims
   }
-
   ## don't need to pass freq, unconditional here as that is done for V
   Xp <- predict(model, newdata = data, type = "lpmatrix", ...)
-  sims <- Xp[, lss_loc, drop = FALSE] %*% t(betas[, lss_loc, drop = FALSE])
-  # handle the offset if present; it is an attribute on the Xp matrix
-  # it is a list - with 1 component if a normal model and `l` components if it
-  # is a model with `l` linear predictors.
-  m_offset <- attr(Xp, "model.offset")
-  if (is.list(m_offset)) {
-    m_offset <- m_offset[[1L]] # only for location ?
-  }
-  if (!is.null(m_offset)) {
-    sims <- sims + m_offset
-  }
-
-  if (isTRUE(identical(scale, "response"))) {
-    ilink <- inv_link(model, parameter = "location")
-    sims <- ilink(sims)
-  }
-
-  colnames(sims) <- paste0(".V", seq_len(NCOL(sims)))
-  sims <- as_tibble(sims)
-  names(sims) <- as.character(seq_len(ncol(sims)))
-  sims <- sims |>
-    add_column(
-      .row = seq_len(nrow(sims)),
-      .parameter = rep("location", nrow(sims))
+  ## predict step; for mvn() and multinom() models, we do want to loop over
+  ##   the linear predictors
+  n_eta <- length(lss_idx) # number of linear predictors to work with
+  if (n_eta > 1L) {
+    # this is where we need to handle non-standard predictions
+    fn <- family_type(model)
+    n_data <- NROW(data)
+    n_lp <- n_eta(model)
+    sims <- lapply(
+      seq_len(n_eta),
+      FUN = \(i, Xp, betas, lss_loc, scale) {
+        pred_fun(Xp, betas, lss_loc[[i]], scale)
+      },
+      Xp = Xp, betas = betas, lss_loc = lss_loc, scale = scale
     )
+    sims <- switch(
+      fn,
+      multivariate_normal = yhat_mvn(sims, n_data, n_lp),
+      multinom = yhat_multinom(sims, n_data, n_lp, fam = family(model))
+    )
+  } else {
+    sims <- pred_fun(Xp, betas, lss_loc, scale) |>
+      add_column(
+        .row = seq_len(nrow(data)),
+        .parameter = rep("location", nrow(data))
+      )
+  }
   sims <- sims |>
     pivot_longer(
       cols = !any_of(c(".row", ".parameter")),
@@ -353,16 +535,61 @@
       names_transform = list(".draw" = as.integer)
     ) |>
     relocate(c(".row", ".draw", ".parameter"), .before = 1L)
-  # sims <- gather(sims, key = ".draw", value = ".fitted",
-  # -.data$.row, -.data$.parameter) |>
-  #   mutate(.draw = as.integer(.data$.draw)) |>
-  #   relocate(c(".row", ".draw", ".parameter"), .before = 1L)
   attr(sims, "seed") <- RNGstate
   ## add classes
   class(sims) <- c("fitted_samples", class(sims))
   sims
 }
 
+`yhat_mvn` <- function(sims, n_data, n_eta) {
+  sims <- sims |>
+    bind_rows() |>
+    add_column(
+      .row = rep(seq_len(n_data), times = n_eta),
+      .parameter = paste0(
+        "response",
+        rep(seq_len(n_eta), each = n_data)
+      )
+    )
+  sims
+}
+
+`yhat_multinom` <- function(sims, n_data, n_eta, fam) {
+  n_y <- n_eta + 1
+  sims <- sims |>
+    bind_rows()
+  n_sim <- NCOL(sims)
+  out <- lapply(
+    sims,
+    FUN = \(x, n_data, n_eta, fam) {
+      r <- fam$predict(fam, eta = matrix(x, ncol = n_eta, nrow = n_data))[[1]]
+      r |>
+        data.frame() |>
+        setNames(nm = paste0("response", seq_len(n_y))) |>
+        as_tibble()
+    },
+    n_data = n_data, n_eta = n_eta, fam = fam
+  ) |>
+    bind_rows() |>
+    add_column(
+      .row = rep(seq_len(n_data), times = n_sim),
+      .draw = rep(seq_len(n_sim), each = n_data),
+      .before = 1L
+    ) |>
+    pivot_longer(
+      cols = -c(".row", ".draw"),
+      cols_vary = "slowest",
+      names_to = ".parameter",
+      values_to = ".fitted"
+    ) |>
+    pivot_wider(
+      id_cols = c(".row", ".parameter"),
+      names_from = ".draw",
+      values_from = ".fitted"
+    )
+  out
+}
+
 #' Draw new response values from the conditional distribution of the response
 #'
 #' Predicted values of the response (new response data) are drawn from the
@@ -424,6 +651,7 @@
 }
 
 #' @export
+#' @rdname predicted_samples
 `predicted_samples.default` <- function(model, ...) {
   stop("Don't know how to sample from the posterior of <",
     class(model)[[1L]], ">",
@@ -435,23 +663,81 @@
 #' @rdname predicted_samples
 #' @importFrom tibble as_data_frame add_column
 #' @importFrom tidyr gather
-`predicted_samples.gam` <- function(model, n = 1, data = newdata, seed = NULL,
-                                    weights = NULL, ..., newdata = NULL) {
+`predicted_samples.gam` <- function(
+  model,
+  n = 1,
+  data = newdata,
+  seed = NULL,
+  weights = NULL,
+  ...,
+  newdata = NULL
+) {
+  
   if (!is.null(newdata)) {
     newdata_deprecated()
   }
 
-  sims <- simulate(model,
-    nsim = n, seed = seed, data = data,
-    weights = weights, ...
+  do_predicted_samples(
+    model = model, n = n, data = data, seed = seed, weights = weights, ...
+  )
+}
+
+#' @export
+#' @rdname predicted_samples
+`predicted_samples.scam` <- function(
+  model,
+  n = 1,
+  data = NULL,
+  seed = NULL,
+  weights = NULL,
+  ...
+) {
+  do_predicted_samples(
+    model = model, n = n, data = data, seed = seed, weights = weights, ...
+  )
+}
+
+`do_predicted_samples` <- function(
+  model,
+  n = 1,
+  data = NULL,
+  seed = NULL,
+  weights = NULL,
+  ...
+) {
+  sims <- simulate(
+    model, nsim = n, seed = seed, data = data, weights = weights, ...
   )
   RNGstate <- attr(sims, "seed")
-  colnames(sims) <- paste0(".V", seq_len(NCOL(sims)))
-  sims <- as_tibble(sims)
-  names(sims) <- as.character(seq_len(ncol(sims)))
-  sims <- add_column(sims, .row = seq_len(nrow(sims)))
-  sims <- gather(sims, key = ".draw", value = ".response", -.row) |>
-    mutate(.draw = as.integer(.data$.draw))
+  class(sims) <- class(sims)[-1] # remove the "simulate_gratia" class
+  if (
+    is_multivariate_y(model) &&
+      identical(family_type(model), "multivariate_normal")
+  ) {
+    # first column is .response for truly multivariate Y models
+    sims <- as_tibble(sims)
+    names(sims)[-1] <- as.character(seq_len(ncol(sims) - 1))
+    n_eta <- n_eta(model)
+    sims <- sims |>
+      add_column(.row = rep(seq_len(nrow(sims) / n_eta), times = n_eta)) |>
+      pivot_longer(
+        cols = !c(".row", ".yvar"),
+        names_to = ".draw",
+        values_to = ".response",
+        names_transform = list(.draw = as.integer)
+      ) |>
+      rename(.parameter = ".yvar") |>
+      relocate(all_of(c(".row", ".draw")), .before = 1L)
+  } else {
+    # rewrite this so it is more like the above with pivot_longer
+    colnames(sims) <- paste0(".V", seq_len(NCOL(sims)))
+    sims <- as_tibble(sims)
+    names(sims) <- as.character(seq_len(ncol(sims)))
+    sims <- add_column(sims, .row = seq_len(nrow(sims)))
+    sims <- gather(sims, key = ".draw", value = ".response", -.row) |>
+      mutate(.draw = as.integer(.data$.draw))
+  }
+
   attr(sims, "seed") <- RNGstate
   ## add classes
   class(sims) <- c("predicted_samples", class(sims))
@@ -534,7 +820,7 @@
 #'   `data` not supplied
 #' @param select character; select which smooth's posterior to draw from.
 #'   The default (`NULL`) means the posteriors of all smooths in `model`
-#'   wil be sampled from. If supplied, a character vector of requested terms.
+#'   will be sampled from. If supplied, a character vector of requested terms.
 #' @param term `r lifecycle::badge("deprecated")` Use `select` instead.
 #' @param rng_per_smooth logical; if TRUE, the behaviour of gratia version
 #' 0.8.1 or earlier is used, whereby a separate call the the random number
@@ -993,7 +1279,8 @@
   envir = environment(formula(object)),
   draws = NULL,
   mvn_method = c("mvnfast", "mgcv"),
-  ...) {
+  ...
+) {
   # deal with deprecation of level
   if (lifecycle::is_present(level)) {
     lifecycle::deprecate_warn(
@@ -1002,6 +1289,56 @@
       details = "`level` was never supported and will be removed in the next release."
     )
   }
+  do_derivative_samples(
+    object = object, focal = focal, data = data, order = order, type = type,
+    scale = scale, method = method, n = n, eps = eps, n_sim = n_sim,
+    seed = seed, envir = envir, draws = draws, mnv_method = mvn_method
+  )
+}
+
+#' @export
+#' @rdname derivative_samples
+`derivative_samples.scam` <- function(
+  object,
+  focal = NULL,
+  data = NULL,
+  order = 1L,
+  type = c("forward", "backward", "central"),
+  scale = c("response", "linear_predictor"),
+  method = c("gaussian", "mh", "inla", "user"),
+  n = 100,
+  eps = 1e-7,
+  n_sim = 10000,
+  seed = NULL,
+  envir = environment(formula(object)),
+  draws = NULL,
+  mvn_method = c("mvnfast", "mgcv"),
+  ...
+) {
+  do_derivative_samples(
+    object = object, focal = focal, data = data, order = order, type = type,
+    scale = scale, method = method, n = n, eps = eps, n_sim = n_sim,
+    seed = seed, envir = envir, draws = draws, mnv_method = mvn_method
+  )
+}
+
+`do_derivative_samples` <- function(
+  object,
+  focal = NULL,
+  data = NULL,
+  order = 1L,
+  type = c("forward", "backward", "central"),
+  scale = c("response", "linear_predictor"),
+  method = c("gaussian", "mh", "inla", "user"),
+  n = 100,
+  eps = 1e-7,
+  n_sim = 10000,
+  seed = NULL,
+  envir = environment(formula(object)),
+  draws = NULL,
+  mvn_method = c("mvnfast", "mgcv"),
+  ...
+) {
   ## handle type
   type <- match.arg(type)
   ## handle method
