@@ -7,13 +7,13 @@
 test_that("draw works for a simple BAM with AR 1", {
   expect_silent(plt <- draw(m_ar1, rug = FALSE))
 
-  skip_on_ci()
+  # skip_on_ci() # testing without as moved to mac os x
   expect_doppelganger("draw bam ar 1 single series", plt)
 })
 
 test_that("draw works for a factor by BAM, 2 series, with AR 1", {
   expect_silent(plt <- draw(m_ar1_by, rug = FALSE))
 
-  skip_on_ci()
+  # skip_on_ci() # testing without as moved to mac os x
   expect_doppelganger("draw bam ar 1 factor by", plt)
 })
