@@ -104,3 +104,36 @@ test_that("fitted values works for a gamm model", {
   expect_silent(fv <- fitted_values(m_gamm))
   expect_named(fv, expected = c(".row", "x0", "x1", "x2", "x3", fv_nms))
 })
+
+test_that("fitted values works for a ziP() model", {
+  # compare predict(m_ziP, type = "response") with fitted_values(m_ziP)
+  f_mgcv <- predict(m_ziP, type = "response") |> as.vector()
+  f_fv   <- fitted_values(m_ziP)$.fitted
+  expect_identical(f_fv, f_mgcv)
+
+  skip_on_cran()
+  skip_on_ci()
+  expect_snapshot(fitted_values(m_ziP))
+})
+
+test_that("fitted values works for a mvn() model", {
+  # compare predict(m_ziP, type = "response") with fitted_values(m_ziP)
+  f_mgcv <- predict(m_mvn, type = "response") |> as.vector()
+  f_fv   <- fitted_values(m_mvn)$.fitted
+  expect_identical(f_fv, f_mgcv)
+
+  skip_on_cran()
+  skip_on_ci()
+  expect_snapshot(fitted_values(m_mvn))
+})
+
+test_that("fitted values works for a multinom() model", {
+  # compare predict(m_ziP, type = "response") with fitted_values(m_ziP)
+  f_mgcv <- predict(m_multinom, type = "response") |> as.vector()
+  f_fv   <- fitted_values(m_multinom)$.fitted
+  expect_identical(f_fv, f_mgcv)
+
+  skip_on_cran()
+  skip_on_ci()
+  expect_snapshot(fitted_values(m_multinom))
+})
